==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/Exception.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_EXCEPTION_H_
#define _D_EXCEPTION_H_

#include "common.h"
#include <string>
#include <stdio.h>
#include <stdarg.h>

using namespace std;

class Exception {
private:
  string msg;
protected:
  Exception* cause;

  void setMsg(const string& msgsrc, va_list ap) {
    char buf[1024];
    vsnprintf(buf, sizeof(buf), msgsrc.c_str(), ap);
    msg = buf;
  }
public:
  Exception(Exception* cause = 0):cause(cause) {}

  virtual ~Exception() {
    delete cause;
  }

  const string& getMsg() const { return msg; }

  Exception* getCause() const { return cause; }

  friend ostream& operator<<(ostream& o, const Exception& e);
};

#endif // _D_EXCEPTION_H_

==> aria2_1.1.2.orig.tar.gz: aria2-1.1.2/src/Exception.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_EXCEPTION_H_
#define _D_EXCEPTION_H_

#include "common.h"
#include "SharedHandle.h"
#include <string>

namespace aria2 {

class Exception:public std::exception {
private:
  std::string _msg;

  SharedHandle<Exception> _cause;

protected:
  virtual SharedHandle<Exception> copy() const = 0;

public:
  explicit Exception(const std::string& msg);

  Exception(const std::string& msg, const Exception& cause);

  Exception(const Exception& e);

  virtual ~Exception() throw();

  virtual const char* what() const throw();

  std::string stackTrace() const throw();
};

} // namespace aria2

#endif // _D_EXCEPTION_H_
